@@ -17,11 +17,11 @@ Kit_SubtitleRenderer* Kit_CreateSubtitleRenderer(Kit_Decoder *dec) {
     return ren;
 }
 
-void Kit_RunSubtitleRenderer(Kit_SubtitleRenderer *ren, void *src, double start_pts, double end_pts) {
+void Kit_RunSubtitleRenderer(Kit_SubtitleRenderer *ren, void *src, double pts, double start, double end) {
     if(ren == NULL)
         return;
     if(ren->ren_render != NULL)
-        ren->ren_render(ren, src, start_pts, end_pts);
+        ren->ren_render(ren, src, pts, start, end);
 }
 
 int Kit_GetSubtitleRendererData(Kit_SubtitleRenderer *ren, Kit_TextureAtlas *atlas, SDL_Texture *texture, double current_pts) {
